@@ -2,13 +2,13 @@
 ;#
 ;# Main file.
 ;#
-;# Copyright (C) Jose E. Marchesi
+;# Copyright (C) 2002-2008 Jose E. Marchesi
 ;#
-;# Time-stamp: "2003-11-11 15:16:30 jemarch"
+;# Time-stamp: "08/11/16 19:20:26 jemarch"
 
 ;# This program is free software; you can redistribute it and/or
 ;# modify it under the terms of the GNU General Public License as
-;# published by the Free Software Foundation; either version 2 of
+;# published by the Free Software Foundation; either version 3 of
 ;# the License, or (at your option) any later version.
 
 ;# This program is distributed in the hope that it will be useful,
@@ -16,13 +16,9 @@
 ;# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;# GNU General Public License for more details.
 
-;# You should have received a copy of the GNU General Public
-;# License along with this program; if not, write to the Free
-;# Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-;# MA 02111-1307 USA
-
-
-
+;# You should have received a copy of the GNU General Public License
+;# along with this program.  If not, see
+;# <http://www.gnu.org/licenses/>.
 
 ;#
 ;# gerwin_init
